@@ -5,8 +5,10 @@ from dateutil.parser import parse
 import re
 import sys
 import uuid
-import pickle
+import inspect
+import json
 
+from amaascore.core.amaas_model import to_json_string
 from amaascore.assets.children import Link
 from amaascore.core.amaas_model import AMaaSModel
 from amaascore.core.comment import Comment
@@ -30,7 +32,7 @@ class Asset(AMaaSModel):
 
     def __init__(self, asset_manager_id, fungible, asset_issuer_id=None, asset_id=None, asset_status='Active',
                  country_id=None, venue_id=None, currency=None, issue_date=date.min,
-                 roll_price=True, display_name='', description='',
+                 roll_price=True, display_name='', description='', maturity_date=date.max,
                  comments=None, links=None, references=None, client_additional=None,
                  *args, **kwargs):
         self.asset_manager_id = asset_manager_id
@@ -47,6 +49,7 @@ class Asset(AMaaSModel):
         self.venue_id = venue_id
         self.currency = currency
         self.issue_date = issue_date
+        self.maturity_date = maturity_date
         self.roll_price = roll_price
         self.display_name = display_name
         self.description = description
@@ -93,6 +96,32 @@ class Asset(AMaaSModel):
         """
         self._maturity_date = parse(value).date() if isinstance(value, type_check) else value
 
+    @property
+    def roll_price(self):
+        if hasattr(self, '_roll_price'):
+            return self._roll_price
+
+    @roll_price.setter
+    def roll_price(self, value):
+        """
+        Always convert to bool if the service/database returns 0 or 1
+        """
+        if value is not None:
+            self._roll_price = True if value else False
+
+    @property
+    def fungible(self):
+        if hasattr(self, '_fungible'):
+            return self._fungible
+
+    @fungible.setter
+    def fungible(self, value):
+        """
+        Always convert to bool if the service/database returns 0 or 1
+        """
+        if value is not None:
+            self._fungible = True if value else False
+
     def __str__(self):
         return "Asset object - ID: %s" % self.asset_id
 
@@ -101,9 +130,9 @@ class Asset(AMaaSModel):
 
     def country_and_venue_codes(self):
         """
-        This function returns dictionary in the format of {"country_codes": [XYZ, ABC], "venue_id": [ABC]} 
+        This function returns dictionary in the format of {"country_codes": [XYZ, ABC], "venue_id": [ABC]}
         Where country_codes = self.country_id and venue_id = self.venue_id
-        except for FX where we also return the country_ids associated with the legs of the FX transaction 
+        except for FX where we also return the country_ids associated with the legs of the FX transaction
         (e.g. USDJPY returns USA + JPN).
         """
         codes = {'country_codes': self.get_country_codes(), 'venue_id': [self.venue_id]}
@@ -114,18 +143,8 @@ class Asset(AMaaSModel):
 
     @property
     def hashcode(self):
-        ignored_attributes = ['version']
-        boolean_attributes = ['fungible', 'roll_price']
-        attributes = {attr: getattr(self, attr) for attr in self.to_dict()
-                      if attr not in boolean_attributes}
-
-        for boolean_attr in boolean_attributes:
-            attributes[boolean_attr] = int(getattr(self, boolean_attr))
-
-        for attr in ['client_additional']:
-            value = getattr(self, attr)
-            if value:
-                dict_value = pickle.loads(value)
-                if dict_value and isinstance(dict_value, dict):
-                    attributes[attr] = dict_value
-        return compute_hash(attributes, ignored_attributes=ignored_attributes)
+        asset_dict = {key: getattr(self, key) for key in self.to_dict() if key != 'hashcode'}
+        type_args = inspect.signature(self.__init__).parameters.keys()
+        ignored_attributes = [key for key in asset_dict if key not in type_args]
+        data = json.loads(to_json_string(asset_dict))
+        return compute_hash(data, ignored_attributes=ignored_attributes)
