@@ -184,6 +184,24 @@ class TransactionsInterface(Interface):
             self.logger.error(response.text)
             response.raise_for_status()
 
+    def upsert_mtm_results(self, asset_manager_id, mtm_results):
+        self.logger.info('Upserting Marking to market Positions - Asset Manager: %s', asset_manager_id)
+        if not isinstance(mtm_results, list):
+            mtm_results = [mtm_results]
+        mtm_result_json = []
+        for mtm_result in mtm_results:
+            mtm_result_json.append(mtm_result.to_interface())
+        url = '%s/mtm/%s' % (self.endpoint, asset_manager_id)
+        response = self.session.post(url, json=mtm_result_json, params={'upsert': True})
+        if response.ok:
+            mtm_results = []
+            for mtm_result_json in response.json():
+                mtm_results.append(json_to_mtm_result(mtm_result_json))
+            return mtm_results
+        else:
+            self.logger.error(response.text)
+            response.raise_for_status()
+
     def amend_mtm_results(self, asset_manager_id, mtm_results):
         self.logger.info('Amending mtm Positions - Asset Manager: %s', asset_manager_id)
         if not isinstance(mtm_results, list):
@@ -218,6 +236,20 @@ class TransactionsInterface(Interface):
             self.logger.error(response.text)
             response.raise_for_status()
 
+    def retrieve_aggregate_pnls(self, asset_manager_id, book_ids, business_date, currency):
+        self.logger.info('Retrieving Aggregate PnL result - Asset Manager: %s - Book IDs: (%s) - Business Date: %s - Currency: %s' % \
+                        (asset_manager_id, ', '.join(book_ids), business_date, currency))
+        url = '%s/aggregate_pnls/%s' % (self.endpoint, asset_manager_id)
+        search_params = {'business_date': business_date,
+                         'book_ids': book_ids,
+                         'currency': currency}
+        response = self.session.get(url, params=search_params)
+        if response.ok:
+            return response.json()
+        else:
+            self.logger.error(response.text)
+            response.raise_for_status()    
+
     def new_transaction_pnls(self, asset_manager_id, transaction_pnls):
         self.logger.info('Insert Transaction PnL results for - Asset Manager: %s', asset_manager_id)
         if not isinstance(transaction_pnls, list):
@@ -231,6 +263,26 @@ class TransactionsInterface(Interface):
             transaction_pnls = []
             for transaction_pnl_json in response.json():
                 transaction_pnls.append(json_to_transaction_pnl(transaction_pnl_json))
+            self.logger.info('Created %s Transaction PnL records', len(transaction_pnls))
+            return transaction_pnls
+        else:
+            self.logger.error(response.text)
+            response.raise_for_status()
+
+    def upsert_transaction_pnls(self, asset_manager_id, transaction_pnls):
+        self.logger.info('Upsert Transaction PnL results for - Asset Manager: %s', asset_manager_id)
+        if not isinstance(transaction_pnls, list):
+            transaction_pnls = [transaction_pnls]
+        transaction_pnl_json = []
+        for transaction_pnl in transaction_pnls:
+            transaction_pnl_json.append(transaction_pnl.to_interface())
+        url = '%s/transaction_pnls/%s' % (self.endpoint, asset_manager_id)
+        response = self.session.post(url, json=transaction_pnl_json, params={'upsert': True})
+        if response.ok:
+            transaction_pnls = []
+            for transaction_pnl_json in response.json():
+                transaction_pnls.append(json_to_transaction_pnl(transaction_pnl_json))
+            self.logger.info('Upserted %s Transaction PnL records', len(transaction_pnls))
             return transaction_pnls
         else:
             self.logger.error(response.text)
@@ -249,6 +301,7 @@ class TransactionsInterface(Interface):
             transaction_pnls = []
             for transaction_pnl_json in response.json():
                 transaction_pnls.append(json_to_transaction_pnl(transaction_pnl_json))
+            self.logger.info('Amended %s Transaction PnL records', len(transaction_pnls))
             return transaction_pnls
         else:
             self.logger.error(response.text)
@@ -270,7 +323,7 @@ class TransactionsInterface(Interface):
         else:
             self.logger.error(response.text)
             response.raise_for_status()
-
+    
     def new_position_pnls(self, asset_manager_id, position_pnls):
         self.logger.info('Insert Position PnL results for - Asset Manager: %s', asset_manager_id)
         if not isinstance(position_pnls, list):
@@ -284,6 +337,26 @@ class TransactionsInterface(Interface):
             position_pnls = []
             for position_pnl_json in response.json():
                 position_pnls.append(json_to_position_pnl(position_pnl_json))
+            self.logger.info('Created %s Position PnL records', len(position_pnls))
+            return position_pnls
+        else:
+            self.logger.error(response.text)
+            response.raise_for_status() 
+
+    def upsert_position_pnls(self, asset_manager_id, position_pnls):
+        self.logger.info('Upsert Position PnL results for - Asset Manager: %s', asset_manager_id)
+        if not isinstance(position_pnls, list):
+            position_pnls = [position_pnls]
+        position_pnl_json = []
+        for position_pnl in position_pnls:
+            position_pnl_json.append(position_pnl.to_interface())
+        url = '%s/position_pnls/%s' % (self.endpoint, asset_manager_id)
+        response = self.session.post(url, json=position_pnl_json, params={'upsert': True})
+        if response.ok:
+            position_pnls = []
+            for position_pnl_json in response.json():
+                position_pnls.append(json_to_position_pnl(position_pnl_json))
+            self.logger.info('Upserted %s Position PnL records', len(position_pnls))
             return position_pnls
         else:
             self.logger.error(response.text)
@@ -302,6 +375,7 @@ class TransactionsInterface(Interface):
             position_pnls = []
             for position_pnl_json in response.json():
                 position_pnls.append(json_to_position_pnl(position_pnl_json))
+            self.logger.info('Amended %s Position PnL records', len(position_pnls))
             return position_pnls
         else:
             self.logger.error(response.text)
@@ -318,7 +392,7 @@ class TransactionsInterface(Interface):
         response = self.session.get(url, params=search_params)
         if response.ok:
             position_pnls = [json_to_position_pnl(json_position_pnl) for json_position_pnl in response.json()]
-            self.logger.info('Returned %s Position PnL results.', len(position_pnls))
+            self.logger.info('Retrieved %s Position PnL results.', len(position_pnls))
             return position_pnls
         else:
             self.logger.error(response.text)
